==> haskell-turtle-1.5.19-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-turtle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 turtle
version:              1.5.19
visibility:           public
id:                   turtle-1.5.19-BCDIj7DswkOCGFyj1FY7hz
key:                  turtle-1.5.19-BCDIj7DswkOCGFyj1FY7hz
license:              BSD-3-Clause
copyright:            2015 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             Shell programming, Haskell-style
description:
    @turtle@ is a reimplementation of the Unix command line environment
    in Haskell so that you can use Haskell as both a shell and a scripting
    language.

    Features include:

    * Batteries included: Command an extended suite of predefined utilities

    * Interoperability: You can still run external shell commands

    * Portability: Works on Windows, OS X, and Linux

    * Exception safety: Safely acquire and release resources

    * Streaming: Transform or fold command output in constant space

    * Patterns: Use typed regular expressions that can parse structured values

    * Formatting: Type-safe @printf@-style text formatting

    * Modern: Supports @text@ and @system-filepath@

    Read "Turtle.Tutorial" for a detailed tutorial or "Turtle.Prelude" for a
    quick-start guide

    @turtle@ is designed to be beginner-friendly, but as a result lacks certain
    features, like tracing commands.  If you feel comfortable using @turtle@
    then you should also check out the @Shelly@ library which provides similar
    functionality.

category:             System
abi:                  bf67b327c1c222afb241dcd33b5139d8
exposed:              True
exposed-modules:
    Turtle Turtle.Bytes Turtle.Format Turtle.Line Turtle.Options
    Turtle.Pattern Turtle.Prelude Turtle.Shell Turtle.Tutorial

hidden-modules:       Turtle.Internal
import-dirs:          /usr/lib/ghc-8.10.1/site-local/turtle-1.5.19
library-dirs:         /usr/lib/ghc-8.10.1/site-local/turtle-1.5.19
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/turtle-1.5.19
hs-libraries:         HSturtle-1.5.19-BCDIj7DswkOCGFyj1FY7hz
depends:
    ansi-wl-pprint-0.6.9-EaGo0Wiiv1e5BdY3Vtwym8
    async-2.2.2-Bj86P845FxLFtoqnXRki4A base-4.14.0.0
    bytestring-0.10.10.0 clock-0.8-4yRBAqo2RabIrS8VkLzaI9
    containers-0.6.2.1 directory-1.3.6.0 exceptions-0.10.4
    foldl-1.4.6-BScekXpZPvML8wLUY0bFGy
    hostname-1.0-AzRHBnbFZcVHzxNmg3d2NQ
    managed-1.0.7-836RZiqJ1BW8RfNUn31AJd
    optional-args-1.0.2-8K9sEgOT794Lg3dgyVmkBl
    optparse-applicative-0.15.1.0-3L3ySBTQF61DHdBg2dIEPu
    process-1.6.8.2 stm-2.5.0.0
    streaming-commons-0.2.1.2-DJOCMER4eXcCrNPyw1vpMS
    system-fileio-0.3.16.4-1a8zjVprwji7YgCSCferIP
    system-filepath-0.4.14-3EHzUlmQbzB1Yt8FKZz4aH
    temporary-1.3-Klb3wRN3u005vIJgMvz9tc text-1.2.3.2 time-1.9.3
    transformers-0.5.6.2 unix-2.7.2.2
    unix-compat-0.5.2-LUrHZKGZjHj4senyv026n5

haddock-interfaces:   /usr/share/doc/haskell-turtle/html/turtle.haddock
haddock-html:         /usr/share/doc/haskell-turtle/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-turtle-1.5.19-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-turtle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 turtle
version:              1.5.19
visibility:           public
id:                   turtle-1.5.19-8dP7lPrNbyfDbsfiNKbaEl
key:                  turtle-1.5.19-8dP7lPrNbyfDbsfiNKbaEl
license:              BSD-3-Clause
copyright:            2015 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             Shell programming, Haskell-style
description:
    @turtle@ is a reimplementation of the Unix command line environment
    in Haskell so that you can use Haskell as both a shell and a scripting
    language.

    Features include:

    * Batteries included: Command an extended suite of predefined utilities

    * Interoperability: You can still run external shell commands

    * Portability: Works on Windows, OS X, and Linux

    * Exception safety: Safely acquire and release resources

    * Streaming: Transform or fold command output in constant space

    * Patterns: Use typed regular expressions that can parse structured values

    * Formatting: Type-safe @printf@-style text formatting

    * Modern: Supports @text@ and @system-filepath@

    Read "Turtle.Tutorial" for a detailed tutorial or "Turtle.Prelude" for a
    quick-start guide

    @turtle@ is designed to be beginner-friendly, but as a result lacks certain
    features, like tracing commands.  If you feel comfortable using @turtle@
    then you should also check out the @Shelly@ library which provides similar
    functionality.

category:             System
abi:                  2cd2d3373a8fa682a4412c6d8e594172
exposed:              True
exposed-modules:
    Turtle Turtle.Bytes Turtle.Format Turtle.Line Turtle.Options
    Turtle.Pattern Turtle.Prelude Turtle.Shell Turtle.Tutorial

hidden-modules:       Turtle.Internal
import-dirs:          /usr/lib/ghc-8.10.1/site-local/turtle-1.5.19
library-dirs:         /usr/lib/ghc-8.10.1/site-local/turtle-1.5.19
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/turtle-1.5.19
hs-libraries:         HSturtle-1.5.19-8dP7lPrNbyfDbsfiNKbaEl
depends:
    ansi-wl-pprint-0.6.9-EaGo0Wiiv1e5BdY3Vtwym8
    async-2.2.2-Bj86P845FxLFtoqnXRki4A base-4.14.0.0
    bytestring-0.10.10.0 clock-0.8-4yRBAqo2RabIrS8VkLzaI9
    containers-0.6.2.1 directory-1.3.6.0 exceptions-0.10.4
    foldl-1.4.6-7oZf2z87pTcEBd23nIW23k
    hostname-1.0-AzRHBnbFZcVHzxNmg3d2NQ
    managed-1.0.7-836RZiqJ1BW8RfNUn31AJd
    optional-args-1.0.2-8K9sEgOT794Lg3dgyVmkBl
    optparse-applicative-0.15.1.0-3L3ySBTQF61DHdBg2dIEPu
    process-1.6.8.2 stm-2.5.0.0
    streaming-commons-0.2.1.2-DJOCMER4eXcCrNPyw1vpMS
    system-fileio-0.3.16.4-1a8zjVprwji7YgCSCferIP
    system-filepath-0.4.14-3EHzUlmQbzB1Yt8FKZz4aH
    temporary-1.3-Klb3wRN3u005vIJgMvz9tc text-1.2.3.2 time-1.9.3
    transformers-0.5.6.2 unix-2.7.2.2
    unix-compat-0.5.2-LUrHZKGZjHj4senyv026n5

haddock-interfaces:   /usr/share/doc/haskell-turtle/html/turtle.haddock
haddock-html:         /usr/share/doc/haskell-turtle/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
